import 'dart:io';

import 'package:example/richtext/example_code.dart';
import 'package:example/richtext/syntax_highlighter.dart';
import 'package:example/ui/ui_kit.dart';
import 'package:flutter/material.dart';

void main() {
  runApp(const MyApp());
}

class MyApp extends StatelessWidget {
  const MyApp({Key? key}) : super(key: key);

  // This widget is the root of your application.
  @override
  Widget build(BuildContext context) {
    return MaterialApp(
      title: 'konkeUI',
      theme: ThemeData(
        primarySwatch: Colors.blue,
      ),
      home: const MyHomePage(title: 'UI组件库'),
    );
  }
}

class MyHomePage extends StatefulWidget {
  const MyHomePage({Key? key, required this.title}) : super(key: key);

  final String title;

  @override
  _MyHomePageState createState() => _MyHomePageState();
}

class _MyHomePageState extends State<MyHomePage> {
  UiKit? select;
  String? code;
  bool isPhone = false;
  var style = SyntaxHighlighterStyle.lightThemeStyle();

  @override
  void initState() {
    try {
      isPhone = Platform.isAndroid || Platform.isIOS;
    } catch (_) {}
    super.initState();
  }

  @override
  Widget build(BuildContext context) {
    return Scaffold(
      appBar: AppBar(
        title: Text(widget.title),
      ),
      body: Row(
        children: [
          SizedBox(
            width: isPhone ? 120 : 300,
            child: ListView(
              children: UiKits.items
                  .map(
                    (e) => InkWell(
                      child: ListTile(
                        title: Text(e.name),
                      ),
                      onTap: () async {
                        String? _code = await ExampleCode.getExampleCode(
                            context,
                            e.path + ".dart",
                            DefaultAssetBundle.of(context));
                        setState(() {
                          select = e;
                          code = _code;
                        });
                      },
                    ),
                  )
                  .toList(),
            ),
          ),
          VerticalDivider(
            color: Colors.grey[200],
            width: 1,
          ),
          Expanded(
            child: Padding(
              padding: const EdgeInsets.all(8.0),
              child: SingleChildScrollView(
                child: Column(
                  crossAxisAlignment: CrossAxisAlignment.start,
                  children: [
                    if (select != null) _titleText("效果展示"),
                    Center(
                      child: select?.demo ?? Container(),
                    ),
                    if (select != null) _titleText("代码示例"),
                    Container(
                      padding: const EdgeInsets.all(8.0),
                      child: SelectableText.rich(
                        TextSpan(
                          style: const TextStyle(fontSize: 12.0),
                          children: <TextSpan>[
                            DartSyntaxHighlighter(style).format(code ?? ""),
                          ],
                        ),
                      ),
                    )
                  ],
                ),
              ),
            ),
          ),
        ],
      ),
    );
  }

  Widget _titleText(String text) => Container(
        padding: const EdgeInsets.fromLTRB(8, 24, 8, 24),
        child: Text(
          text,
          style: const TextStyle(fontSize: 24),
        ),
      );
}
